@@ -64,10 +64,15 @@ class Geo_common:
             r2s = self.samples[line[0]]["raw_file_r2"]
             if len(r1s) != len(r2s):
                 exit("错误: %s 的R1和R2文件数量不相等" %(line[0]))
+            l1 = 0                                                      # read测序长度, 只取R1的第一个数据
             for r1,r2 in zip(r1s,r2s):
+                if not l1:
+                    f1,i1,l1 = FastqToFC.flowcell_lane(r1)                  
                 if_same = FastqToFC.diff_r1_r2(r1,r2)
                 if not if_same:
                     exit("错误: %s 与 %s 不是对应的双端序列!" %(r1,r2))
+                # 测序reads长度 
+            self.samples[line[0]]["length"] = str(l1)
         # groups: 每个比对组包含的样本 , dict = {group1 : [sample1 , smaple2] , group2 : [sample3 , sample4]}
         self.groups = collections.defaultdict(list)
         for sample in self.samples:
